@@ -1,10 +1,13 @@
 """ Using ManagerLive to make batches """
+import logging
 from datetime import datetime
 
 from nowcasting_dataset.manager.manager_live import ManagerLive
 
 from nowcasting_forecast.utils import floor_30_minutes_dt
 
+logger = logging.getLogger(__name__)
+
 
 def make_batches(
     config_filename: str = "nowcasting_forecast/config/mvp_v0.yaml",
@@ -12,6 +15,8 @@ def make_batches(
 ):
     """Make batches from config file"""
 
+    logger.info(f"Making batches using configuration file: {config_filename}")
+
     if t0_datetime_utc is None:
         t0_datetime_utc = floor_30_minutes_dt(datetime.utcnow())  # add timezone
 
