@@ -15,9 +15,8 @@ from nowcasting_forecast.database.fake import make_fake_input_data_last_updated
 from nowcasting_forecast.database.models import (
     Forecast,
     ForecastSQL,
-    ForecastValue,
+    ForecastValueSQL,
     InputDataLastUpdatedSQL,
-    Location,
 )
 from nowcasting_forecast.database.national import make_national_forecast
 from nowcasting_forecast.database.read import get_location
@@ -36,6 +35,8 @@ def nwp_irradiance_simple_run_all_batches(
 ) -> List[ForecastSQL]:
     """Run model for all batches"""
 
+    logger.info("Running nwp_irradiance_simple model")
+
     # time now rounded down by 30 mins
     t0_datetime_utc = floor_30_minutes_dt(datetime.now(timezone.utc))
     logger.info(f"Making forecasts for {t0_datetime_utc=}")
@@ -74,21 +75,21 @@ def nwp_irradiance_simple_run_all_batches(
         )
         forecasts = forecasts[0:N_GSP]
 
-    # convert to sql objects
-    forecasts_sql = [f.to_orm() for f in forecasts]
+    # convert to pydantic objects, for validation
+    _ = [Forecast.from_orm(f) for f in forecasts]
 
     if add_national_forecast:
         # add national forecast
         try:
-            forecasts_sql.append(make_national_forecast(forecasts=forecasts, n_gsps=n_gsps))
+            forecasts.append(make_national_forecast(forecasts=forecasts, n_gsps=n_gsps))
         except Exception as e:
             logger.error(e)
             # TODO remove this
             logger.error("Did not add national forecast, carry on for the moment")
 
-    logger.info(f"Made {len(forecasts_sql)} forecasts")
+    logger.info(f"Made {len(forecasts)} forecasts")
 
-    return forecasts_sql
+    return forecasts
 
 
 def nwp_irradiance_simple_run_one_batch(
@@ -96,7 +97,7 @@ def nwp_irradiance_simple_run_one_batch(
     batch_idx: int,
     session: Session,
     input_data_last_updated: Optional[InputDataLastUpdatedSQL] = None,
-) -> List[Forecast]:
+) -> List[ForecastSQL]:
     """Run model for one batch"""
 
     # make sure its a Batch object
@@ -122,8 +123,6 @@ def nwp_irradiance_simple_run_one_batch(
         gsp_id = i + batch_idx * batch.metadata.batch_size
 
         location = get_location(gsp_id=gsp_id, session=session)
-        logger.debug(location)
-        location = Location.from_orm(location)
 
         forecast_values = []
         for t_index in irradiance_mean.time_index:
@@ -134,14 +133,14 @@ def nwp_irradiance_simple_run_one_batch(
             )
 
             forecast_values.append(
-                ForecastValue(
+                ForecastValueSQL(
                     target_time=target_time,
-                    expected_power_generation_megawatts=irradiance_mean[i, t_index],
+                    expected_power_generation_megawatts=irradiance_mean[i, t_index].values[0],
                 )
             )
 
         forecasts.append(
-            Forecast(
+            ForecastSQL(
                 model_name="mvp_irradence_v0",
                 location=location,
                 forecast_creation_time=forecast_creation_time,
@@ -171,6 +170,6 @@ def nwp_irradiance_simple(batch: Batch) -> xr.DataArray:
     irradence_mean = nwp.data.mean(axis=(2, 3))
 
     # scale irradence to roughly mw
-    irradence_mean = irradence_mean / 100
+    irradence_mean = irradence_mean / 10
 
     return irradence_mean
